pub enum QRType {
Static,
Dynamic,
Hybrid,
}Variants
Static
QR payment that can be paid more than once.
Dynamic
QR payment that can be paid once.
Hybrid
QR payment can pe paid more than once.
This also allows to modify amount and expiration date while is considere valid payment.